// Copyright (c) 2010 Keith D Gregory, all rights reserved
package com.kdgregory.app.s3util.s3ops;

import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import net.sf.s34j.rest.S3Service;

import com.kdgregory.app.s3util.main.Concierge;


/**
 *  Retrieves a list of buckets associated with the current user.
 */
public class S3BucketListOp
extends AbstractS3Op<List<String>>
{
    /**
     *  The recipient of this list must implement this interface. At present
     *  there's only one recipient, the bucket selection dialog. When I was
     *  originally working on this operation, I thought there might be more.
     *  I left the callback interface in place because it's a better design.
     */
    public interface Callback
    {
        void setBucketList(List<String> list);
    }


//----------------------------------------------------------------------------
//  Instance Data and Constructor
//----------------------------------------------------------------------------

    private Log _logger = LogFactory.getLog(this.getClass());

    private Callback _callback;


    public S3BucketListOp(Concierge concierge, Callback callback)
    {
        super(concierge, "Retrieving list of buckets");
        _callback = callback;
    }


//----------------------------------------------------------------------------
//  Operation
//----------------------------------------------------------------------------

    @Override
    protected List<String> performOperation()
    throws Exception
    {
        _logger.debug("starting request");
        S3Service service = getFactory().newService();
        List<String> buckets = service.listBuckets();
        _logger.debug("request complete");

        return buckets;
    }


    @Override
    protected void onSuccess(List<String> buckets)
    {
        _callback.setBucketList(buckets);
    }
}
