// Copyright (c) 2010 Keith D Gregory, all rights reserved
package com.kdgregory.app.s3util.s3ops;

import java.util.List;
import javax.swing.SwingUtilities;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import net.sf.s34j.rest.S3Object;

import com.kdgregory.app.s3util.filelist.S3File;
import com.kdgregory.app.s3util.main.Concierge;


/**
 *  Deletes one or more files from S3, reporting each back to the main frame.
 */
public class S3DeleteOp
extends AbstractS3Op<Object>
{
    private Log _logger = LogFactory.getLog(this.getClass());

    private List<S3File> _files;

    public S3DeleteOp(Concierge concierge, List<S3File> files)
    {
        super(concierge, "Deleting file(s)");
        _files = files;
    }


//----------------------------------------------------------------------------
//  Operation
//----------------------------------------------------------------------------

    @Override
    protected Object performOperation()
    throws Exception
    {
        _logger.debug("starting request");
        for (S3File file : _files)
        {
            _logger.debug(file);
            String key = file.getKey();
            S3Object obj = createS3Object(key);
            obj.delete();
            reportFileDeleted(file);
        }
        _logger.debug("request complete");
        return null;
    }


//----------------------------------------------------------------------------
//  Internals
//----------------------------------------------------------------------------


    private void reportFileDeleted(final S3File file)
    {
        SwingUtilities.invokeLater(new Runnable()
        {
            public void run()
            {
                getConcierge().getMainFrame().deleteFile(file);
            }
        });
    }
}