// Copyright (c) 2010 Keith D Gregory, all rights reserved
package com.kdgregory.app.s3util.s3ops;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import javax.swing.SwingUtilities;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import net.sf.s34j.defines.S3CannedAcl;
import net.sf.s34j.rest.S3Object;

import com.kdgregory.app.s3util.filelist.S3File;
import com.kdgregory.app.s3util.main.Concierge;
import com.kdgregory.app.s3util.util.MimeHelper;


/**
 *  Uploads a file to S3. If given a directory, will recurse through
 *  the contents of that directory.
 */
public class S3UploadOp
extends AbstractS3Op<Object>
{
    private Log _logger = LogFactory.getLog(this.getClass());

    private List<S3File> _files;
    private boolean _makePublic;

    public S3UploadOp(
            Concierge concierge,
            File[] files,
            String destination,
            boolean makePublic)
    {
        super(concierge, "Uploading file(s)");

        _files = new ArrayList<S3File>(files.length);
        for (File file : files)
            _files.add(new S3File(file, destination));
        _makePublic = makePublic;
    }


//----------------------------------------------------------------------------
//  Operation
//----------------------------------------------------------------------------

    @Override
    protected Object performOperation()
    throws Exception
    {
        _logger.debug("starting request");
        _logger.debug("public read flag: " + _makePublic);
        for (S3File file : _files)
            writeFileRecursive(file);
        _logger.debug("request complete");
        return null;
    }


//----------------------------------------------------------------------------
//  Internals
//----------------------------------------------------------------------------

    private void writeFileRecursive(S3File uploadRequest)
    throws Exception
    {
        _logger.debug(uploadRequest);

        File localFile = uploadRequest.getFile();
        if (localFile.isDirectory())
        {
            String s3Path = uploadRequest.getS3Path() + "/" + localFile.getName();
            for (File child : localFile.listFiles())
            {
                writeFileRecursive(new S3File(child, s3Path));
            }
        }
        else
        {
            S3Object obj = createS3Object(uploadRequest.getKey());
            if (_makePublic)
                obj.setAcl(S3CannedAcl.PUBLIC_READ);
            obj.write(localFile, MimeHelper.lookup(localFile));
            reportFileUploaded(uploadRequest);
        }
    }


    private void reportFileUploaded(final S3File file)
    {
        SwingUtilities.invokeLater(new Runnable()
        {
            public void run()
            {
                getConcierge().getMainFrame().addFile(file);
            }
        });
    }
}
